@@ -418,6 +418,13 @@ int fit_iforest(IsoForest *model_outputs, ExtIsoForest *model_outputs_ext,
 
     /* Global variable that determines if the procedure receives a stop signal */
     interrupt_switch = false;
+    /* TODO: find a better way of handling interrupt signals when calling in Python/R.
+       The following will still change the behavior of interrupts when called through e.g. Flask */
+    #if !defined(_WIN32) && !defined(_WIN64) && !defined(_MSC_VER)
+    struct sigaction sig_handle;
+    sig_handle.sa_flags = SA_RESETHAND;
+    sig_handle.sa_handler = set_interrup_global_variable;
+    #endif
 
     /* grow trees */
     #pragma omp parallel for num_threads(nthreads) schedule(dynamic) shared(model_outputs, model_outputs_ext, worker_memory, input_data, model_params)
@@ -461,7 +468,11 @@ int fit_iforest(IsoForest *model_outputs, ExtIsoForest *model_outputs_ext,
         else
             model_outputs_ext->hplanes[tree].shrink_to_fit();
 
+        #if !defined(_WIN32) && !defined(_WIN64) && !defined(_MSC_VER)
+        sigaction(SIGINT, &sig_handle, NULL);
+        #else
         signal(SIGINT, set_interrup_global_variable);
+        #endif
     }
 
     /* check if the procedure got interrupted */
